Package {compIndexBuilder}


Type: Package
Title: Composite Index Builder & Analytics 'shiny' App
Version: 2.0.0
Author: Hossein Hassani [aut], Steve Macfeely [aut], Petra Kynclova [aut], Nour Barnat [aut], Leila Marvian Mashhad [aut, cre], Fernando CANTU BAZALDUA [aut]
Maintainer: Leila Marvian Mashhad <leila.marveian@gmail.com>
Description: Provides an interactive 'shiny' application for constructing, analysing, comparing, and visualising composite indices from tabular multidimensional data. Supports multi-sheet 'Excel' workbooks with active-sheet selection, refresh controls, per-sheet and workbook-wide exports, missing-data processing, indicator direction and normalisation controls, equal and custom weighting, entity-level ranking, time-series analysis and forecasting, entity comparisons, pillar-based sub-indices with equal, custom, correlation-based, or principal-component weights, and diagnostic tools including internal-consistency reliability assessment, coefficient of variation, principal component analysis, sensitivity analysis, correlation heatmaps, and weighted flow visualizations.
License: GPL-3
Encoding: UTF-8
Depends: R (≥ 4.1.0)
Imports: shiny, shinydashboard, DT, plotly, ggplot2, dplyr, readxl, forecast, tidyr, networkD3, psych, corrplot, missForest, zoo, jsonlite
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-08-19 16:43:21 UTC; marvian
Repository: CRAN
Date/Publication: 2026-08-19 22:00:22 UTC

Composite Index Builder and Analytics Shiny Application

Description

Provides an interactive Shiny application for building and analysing composite indices from multidimensional tabular data. Version 2 supports multi-sheet Excel workbooks, sheet-level exports, data processing, custom and pillar-based weighting, rankings, time-series analysis, forecasting, comparisons, and statistical diagnostics.

Details

Launch the application in an interactive R session with compIndexBuilder().

Author(s)

Hossein Hassani, Steve Macfeely, Petra Kynclova, Nour Barnat, Leila Marvian Mashhad, and Fernando CANTU BAZALDUA.

Maintainer: Leila Marvian Mashhad <leila.marveian@gmail.com>


Launch the Composite Index Builder Shiny Application

Description

Launches the interactive Shiny application bundled with compIndexBuilder. The application supports CSV and multi-sheet Excel workbooks, composite-index construction, weighting, diagnostics, time-series analysis, forecasting, comparisons, and pillar-based sub-indices.

Usage

compIndexBuilder(...)

Arguments

...

Additional arguments passed to shiny::runApp(), such as launch.browser, host, or port.

Value

Invisibly returns the value returned by shiny::runApp(). The function is primarily called for its side effect of launching the Shiny application.

Examples

if (interactive()) {
  compIndexBuilder()
}